@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: http-client
-version: 0.4.27
-id: http-client-0.4.27-1cd31210c8ec4a6e0b4cc467bd24f592
-key: httpc_2ftXothlM7QEUjpCnKv1nA
+version: 0.4.28
+id: http-client-0.4.28-3a5d04f7eb5922409c889a37b339ae0f
+key: httpc_JZzGxbBWSal9HBI491lULR
 license: MIT
 maintainer: michael@snoyman.com
 homepage: https://github.com/snoyberg/http-client
@@ -25,30 +25,30 @@ hidden-modules: Network.HTTP.Client.Body
                 Network.PublicSuffixList.Types Network.PublicSuffixList.Serialize
                 Network.PublicSuffixList.DataStructure
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/http-client-0.4.27
-library-dirs: /usr/lib/ghc-7.10.3/site-local/http-client-0.4.27
-data-dir: /usr/share/arm-linux-ghc-7.10.3/http-client-0.4.27
-hs-libraries: HShttp-client-0.4.27-2ftXothlM7QEUjpCnKv1nA
+import-dirs: /usr/lib/ghc-7.10.3/site-local/http-client-0.4.28
+library-dirs: /usr/lib/ghc-7.10.3/site-local/http-client-0.4.28
+data-dir: /usr/share/arm-linux-ghc-7.10.3/http-client-0.4.28
+hs-libraries: HShttp-client-0.4.28-JZzGxbBWSal9HBI491lULR
 depends:
     array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
-    blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
+    blaze-builder-0.4.0.2-290873936811c5be5456133d1e8642df
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    case-insensitive-1.2.0.6-c6baeb35be7a5ef7e8151f5e00d87f59
+    case-insensitive-1.2.0.6-f940e4aded76d28f250fda2e1500b30b
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    cookie-0.4.1.6-97fa5cf54d4ed1e2644dbcebe7255b51
+    cookie-0.4.2-28e8510d867302127f61174b072159ee
     data-default-class-0.0.1-fcbab95490d730dd2489b628499587cd
     deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
     exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
     filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
     ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
-    http-types-0.9-a274b17bf4f057225e6c0af6d57f03ec
-    mime-types-0.1.0.6-7d5f22022675c00ea07fd0f1df020c2e
+    http-types-0.9-abc209b9e91b870b477d7ec7669b4ae8
+    mime-types-0.1.0.7-9c54fcb2a9f57168849ef5415f3582c2
     network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
-    network-uri-2.6.1.0-0e39aca8530572505c01ef548c540bd6
+    network-uri-2.6.1.0-522aa8cc2805dab5af7064f70c4a777d
     random-1.1-41a0a7ecd483c665a5c3a093a5be2968
-    streaming-commons-0.1.15.2-e8e35f9b3c5e3a1a9d565bf7c4ec1900
+    streaming-commons-0.1.15.5-b71913214a53247591329436a8fa2523
     text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
